CON
  _clkmode = xtal1 + pll16x     
  _xinfreq = 5_000_000

  SR_CLOCK        = 0                    { lcd driver }
  SR_LATCH        = 1                    { lcd driver }
  SR_DATA         = 2                    { lcd driver }

  Led_1           = 9                    { Temp Led }
  Led_2           = 10                    { LV Led }
  Led_3           = 11                   { CO2 Led }
  Led_4           = 12                   { Histories Max Led }
  Led_5           = 13                   { Histories Min Led }
  Led_6           = 14                   { Setpoint Day }
  Led_7           = 15                   {Setpoint Night }

  ADC_3           = 18                   {ADC control }
  ADC_2           = 17                   {ADC control }
  ADC_1           = 16                   {ADC control }

  SHT_CLK         = 19                   { TEMP/ RV sensor}
  SHT_DATA        = 20                   { TEMP/ RV sensor}

  Relay_3         = 21                   {SSR Control}
  Relay_2         = 22                   {SSR Control}
  Relay_1         = 23                   {SSR Control}

  buton1          = 24                   { push buttons }
  buton2          = 25                   { push buttons }
  buton3          = 26                   { push buttons }
  buton4          = 27                   { push buttons }

  BUFFER_2K     = $800
  
  CR            = $0D
  LF            = $0A
  NULL          = $00

  SOCKETS       = 8
  
  #0, CLOSED, TCP, UDP, IPRAW, MACRAW, PPPOE

    

  Zero_Out = 0                  {valvue to reset historic reading}

  i2cSCL        = 28   
  EEPROMAddr    = %1010_0000
    
VAR
  long  seed
  byte templock,notactive

  byte  temp[32]                               {input temp }
  byte  lv[32]                                 {input lv }
  long tempC,tempC1,tempC2,tempC3              {global temp vars }
  long lv1,lv2,lv3                             {global lv vars }

  long tempmax,tempmin       {Historis Min /Max Temp Variabelen }
  long lvmax,lvmin ,eepromData          {Historis Min /Max LV Variabelen }      


  byte h_menu                     { Hoofdmenu Variabele }
  long stack1[128] ,stack2[128]   {stackspace for new cog }

  long reading,  dig1,dig11,  dig2,dig22,  dig3,dig33,  dig4,dig44               { decodeer berekening waardes }
  long waarde1,waarde11,  waarde2,waarde22,  waarde3,waarde33,  waarde4,waarde44 { decodeer berekening waardes }
   
  long Setpoint,Offset                         { aanstuur waardes }
  long teller1,teller2 ,screen,punt
  long numleds_, firstled_, persistence_, leds[7] 

OBJ
  pst             : "Parallax Serial Terminal"
  wiz             : "W5200.spin" 
  sock[SOCKETS]   : "Socket.spin"
  sht             : "Sensirion_full"         { temp/lv sensor control object }
  fp              : "FloatString"              { Math object }
  f               : "Float32"                  { Math object }
  i2cObject       : "basic_i2c_driver"         {Eprom object}     
  shift           : "Simple_74HC595"             { lcd control object }             
  rom             : "I2C_ROMEngine"                       { Eeprom Backup object }
  led             : "led_pwm"   
PUB Main | i, page

   setpoint :=  i2cObject.ReadLong(i2cSCL, EEPROMAddr, $6981) 
  offset :=  i2cObject.ReadLong(i2cSCL, EEPROMAddr, $6977)
    
  dira[8]~~
  outa[8]~~
  
  cognew(tempcontrol,@stack1)
  cognew(controller,@stack2)
  
  pst.Start(115_200)
  pause(1000)

  wiz.Init
    
  wiz.SetIp(192, 168, 2, 200)

  wiz.SetMac($00, $08, $DC, $16, $F8, $01)
    pause(500) 
  
  repeat
    pst.str(string("Initialize Sockets",CR))
    repeat i from 0 to SOCKETS-1
      sock[i].Init(i, TCP, 8080)
           
    OpenListeners
    StartListners
        
    pst.str(string("Start Socket server",CR))
    \MultiSocketServer
    pst.str(string("I blew up!"))
    pause(5000)


  
PUB OpenListeners | i
  pst.str(string("Open",CR))
  repeat i from 0 to SOCKETS-1  
    sock[i].Open
      
PUB StartListners | i
  repeat i from 0 to SOCKETS-1
    if(sock[i].Listen)
      pst.str(string("Listen "))
    else
      pst.str(string("Listener failed ",CR))
    pst.dec(i)
    pst.char(CR)

PUB CloseWait | i
  repeat i from 0 to SOCKETS-1
   
    if(sock[i].IsCloseWait) 
      sock[i].Disconnect
      sock[i].Close
      
    if(sock[i].IsClosed)  
      sock[i].Open
      sock[i].Listen

PUB MultiSocketServer | bytesToRead, i, page, j, x , bytesSent, ptr
  bytesToRead := bytesSent := i := j := x := 0
  repeat
    pst.str(string("TCP Service", CR))
    CloseWait

    repeat j from 0 to SOCKETS-1
      pst.str(string("Socket "))
      pst.dec(j)
      pst.str(string(" = "))
      pst.hex(wiz.GetSocketStatus(j), 2)
      pst.char(13)
     
    repeat until sock[i].Connected
      i := ++i // SOCKETS

    pst.str(string("Connected Socket "))
    pst.dec(i)
    pst.char(CR)
    
    'Data in the buffer?
    repeat until bytesToRead := sock[i].Available

    'Check for a timeout
    if(bytesToRead < 0)
      pst.str(string("Timeout",CR))
      sock[i].Disconnect
      sock[i].Open
      sock[i].Listen
      bytesToRead~
      next

    pst.str(string("Copy Rx Data",CR))
  
    'Get the Rx buffer  
    sock[i].Receive(@buff, bytesToRead)

    {{ Process the Rx data}}
    pst.char(CR)
    pst.str(string("Request:",CR))
    'pst.str(@buff)

    pst.str(string("Send Response",CR))
    page :=  ParseResource(@buff)
    
    pst.str(page)
    pst.char(CR)
    pst.str(string("Byte to send "))
    pst.dec(strsize(page))
    pst.char(CR)

    bytesSent := 0
    ptr := page
    repeat until bytesSent == strsize(page)
      bytesSent += sock[i].Send(ptr, strsize(ptr))
      ptr := page + bytesSent

    pst.str(string("Bytes Sent "))
    pst.dec(bytesSent)
    pst.char(CR)

    pst.str(string("Disconnect socket "))
    pst.dec(i)
    pst.char(CR)

    if(sock[i].Disconnect)
      pst.str(string("Disconnected", CR))
    else
      pst.str(string("Force Close", CR))
    sock[i].Open
    sock[i].Listen
    sock[i].SetSocketIR($FF)
    
    i := ++i // SOCKETS
    bytesToRead~
    
{
PUB ParseResource(header) | ptr, value
  ptr := header
  repeat until byte[ptr++] == $2F '/ forward slash
  if(byte[ptr] == $20) ' space
    return @index
  else
    value := GetTemp
    SetTemp(tempc3)
    Setlv(lv3)
    return @xml
}

PUB ParseResource(header) | ptr, value, i, done, j
  ptr := header
  i := 0
  done := false

  repeat until IsEndOfLine(byte[ptr])
    if(IsToken(byte[ptr]))
      byte[ptr] := 0
      resPtr[i++] := ++ptr
    else
      ++ptr

    if(ptr - header > 500)
      pst.str(string(CR, "+++++++++++++++[ERROR]++++++++++++++",CR))
      return @index

  resPtr[0] := header
  repeat j from 0 to i-1
    pst.str(string("ID"))
    pst.dec(j)
    pst.char($20)
    pst.str(resPtr[j])
    pst.char(CR)

  repeat j from 0 to i-1
    if(strcomp(resPtr[j], string("HTTP")))
      return @index

    if(strcomp(resPtr[j], string("halo")))
      return @halo

      
    if(strcomp(resPtr[j], string("xmltemp")))
      value := GetTemp
      Settemp(tempc3,@temperature)
      Setlv(lv3,@lvlv)
      Settemp(tempmax,@t_max)
      Settemp(tempmin,@t_min)
      Setlv(lvmax,@lv_max)
      Setlv(lvmin,@lv_min)
      Setlv(setpoint,@Set_p)
      Setlv(offset,@off_s)
      return @xml

  
PUB IsToken(value)
  return lookdown(value: "/", "?", "=", " ")

PUB IsEndOfLine(value)
  return lookdown(value: CR, LF)

PUB GetTemp
  seed := CNT 
  ?seed
  return seed & $0F + 1
  
PUB Settemp(value,plaats) | t1
  t1 := value
  t1 := t1/100
  value -= t1 * 100
  if(t1 > 0 and t1 < 9)
    byte[plaats][0] := t1 + $30
  else
    ResetTemp
    return 

  t1 := value
  t1 := t1/10
  value -= t1 * 10
  if(t1 > 0 and t1 < 9) 
    byte[plaats][1] := t1 + $30
  else
    ResetTemp
    return
    
  t1 := value
  if(t1 > 0 and t1 < 9)  
    byte[plaats][3] := t1 + $30
  else
    ResetTemp
    return
    
PUB SetLV(value,plaats) | t1                                              
  t1 := value
 

  t1 := value
  t1 := t1/10
  value -= t1 * 10
  'if(t1 > 0 and t1 < 9) 
    byte[plaats][0] := t1 + $30
  'else
    'ResetTemp
    'return
    
  t1 := value
  if(t1 > 0 and t1 < 9)  
    byte[plaats][1] := t1 + $30
  else
    ResetTemp
    return
  

PUB ResetTemp
  byte[12] := $30
  byte[13] := $30
  byte[14] := $30  
     



     
PUB PrintIp(addr) | i
  repeat i from 0 to 3
    pst.dec(byte[addr][i])
    if(i < 3)
      pst.char($2E)
    else
      pst.char($0D)
  
PRI pause(Duration)  
  waitcnt(((clkfreq / 1_000 * Duration - 3932) #> 381) + cnt)
  return

PUB Controller
  persistence_ := 0
  numleds_ := 7
  firstled_ := 9

  

  shift.init(SR_CLOCK, SR_LATCH, SR_DATA)              {init lcd driver }
  intro

  
  dira[buton1]~                               {make button input}                           
  dira[buton2]~                               {make button input}
  dira[buton3]~                               {make button input}
  dira[buton4]~                               {make button input}

  dira[led_1]~~                                {make Led output}
  dira[led_2]~~                                {make Led output}
  dira[led_3]~~                                {make Led output}
  dira[led_4]~~                                {make Led output}
  dira[led_5]~~                                {make Led output}
  dira[led_6]~~                                {make Led output}
  dira[led_7]~~                                {make Led output}


  

  
  h_menu:=  1                                           {Set LCD to home menu}
    
  repeat
  
     if ina[buton3]==0                           { down right button}
        h_menu:= h_menu + 1  
        teller1 := teller2 := notactive:= 0
        if h_menu == 9                            {menu size = 8}
          h_menu := 1
        waitcnt (clkfreq /4+ cnt)
                                             
     if ina[buton4]     ==0                           {up left button }
       h_menu:=h_menu - 1
       teller1 := teller2 := notactive:= 0
       if h_menu ==0                              {menu size = 8}
          h_menu:= 8                                            
       waitcnt (clkfreq / 4+ cnt)

                  
     if h_menu > 9
        h_menu:= 0

     
     if h_menu < 1
        h_menu:= 8
     
    '''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''         
     if ina[buton1]==0  and h_menu == 3             {Return to Start Menu from lv reading 'IF UP BUTTON PRESED'}
           waitcnt (clkfreq / 4+ cnt)
           h_menu:=  1

     if ina[buton1]==0  and h_menu == 4             {Return to Start Menu from historic max temp reading 'IF UP BUTTON PRESED'}
           waitcnt (clkfreq / 4+ cnt)
           h_menu:=  1

     if ina[buton1]==0  and h_menu == 5             {Return to Start Menu from historic min temp reading 'IF UP BUTTON PRESED'}
           waitcnt (clkfreq / 4+ cnt)
           h_menu:=  1

     if ina[buton1]==0  and h_menu == 6             {Return to Start Menu from historic max lv reading 'IF UP BUTTON PRESED'}
           waitcnt (clkfreq / 4+ cnt)
           h_menu:=  1

     if ina[buton1]==0  and h_menu == 7             {Return to Start Menu from historic min lv reading 'IF UP BUTTON PRESED'}
           waitcnt (clkfreq / 4+ cnt)
           h_menu:=  1
   '''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
    if ina[buton2]==0  and h_menu == 3                {'IF DOWN BUTTON PRESED'when at MAX TEMP menu }
       waitcnt (clkfreq * 2 + cnt)                    {wait 2 sec and check if still presed }
       if ina[buton2]==0  and h_menu == 3             
           waitcnt (clkfreq / 4 + cnt)
           i2cObject.WriteLong(i2cSCL, EEPROMAddr, $6989,Zero_Out)         {RESET HISTORIC MAX TEMP }
           tempmax:=tempC3                          {SET NEW MAX TEMP HISTORIC TO CURRENT TEMP }
                                               '''''''''''''''''''''''''''''''''''''''''''
    if ina[buton2]==0  and h_menu == 4             {'IF DOWN BUTTON PRESED' when at MIN TEMP menu }
       waitcnt (clkfreq * 2 + cnt)                 {wait 2 sec and check if still presed }
        if ina[buton2]==0  and h_menu == 4
           waitcnt (clkfreq / 4 + cnt)
           i2cObject.WriteLong(i2cSCL, EEPROMAddr, $6985,Zero_Out)         {RESET HISTORIC MIN TEMP }
           tempmin:=tempC3                          {SET NEW MIN TEMP HISTORIC TO CURRENT TEMP } 
                                               '''''''''''''''''''''''''''''''''''''''''''
    if ina[buton2]==0  and h_menu == 5             {'IF DOWN BUTTON PRESED' when at MAX LV menu }
       waitcnt (clkfreq * 2 + cnt)                  {wait 2 sec and check if still presed }
       if ina[buton2]==0  and h_menu == 5
           waitcnt (clkfreq / 4 + cnt)
           i2cObject.WriteLong(i2cSCL, EEPROMAddr, $6997,Zero_Out)         {RESET HISTORIC MAX LV }
           lvmax:=lv3                          {SET NEW MAX LV HISTORIC TO CURRENT LV }
                                               '''''''''''''''''''''''''''''''''''''''''''
    if ina[buton2]==0  and h_menu == 6             {'IF DOWN BUTTON PRESED when at MIN LV menu '}
       waitcnt (clkfreq * 2 + cnt)                  {wait 2 sec and check if still presed }
        if ina[buton2]==0  and h_menu == 6
           waitcnt (clkfreq  / 4 + cnt)               
           i2cObject.WriteLong(i2cSCL, EEPROMAddr, $6993,Zero_Out)         {RESET HISTORIC MIN LV }
           lvmin:=lv3                          {SET NEW MIN LV HISTORIC TO CURRENT LV } 
    ''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
    tellerchek
    
    case  h_menu
       1:
         step1
         punt:= 1
         teller_1
         teller_2
         print(long[@tempc3])
                
       2:
         step2
         punt:= 0
         punt:= 0 
         teller_1
         teller_2
         print(long[@lv3])
        
       3:  
         step3
         punt:= 1
         teller_1
         print(long[@tempmax])
         
       4:
        step4
        punt:= 1
        teller_1
        print(long[@tempmin])
        
       5:  
         step5
         punt:= 0
         teller_1
         print(long[@lvmax])
         
       6:
        step6
        punt:= 0
        teller_1
        print(long[@lvmin ])
        
       7:  
         step7
         instel_setpoint
         
         
         
       8:
        step8
        instel_Offset
        
        
        
  waitcnt(clkfreq + cnt)

PUB tellerchek

    if teller1 > 60000                                { return to Temp Reading if Noting Happening for 30 sec }
       teller1 := 0
       h_menu := 1
       notactive := 1
        
    if teller2 > 30000   and h_menu == 1                          { Scroll from Temp to RV% after 45 sec nothing happen}
       teller2 := 0
       h_menu := 2
        
    if teller2 > 30000   and h_menu == 2              { Scroll from RV% to Temp after 15 sec nothing happen }
       teller2 := 0
       h_menu := 1
       
PUB teller_1

  teller1:=teller1 + 1
  return
PUB teller_2
  if notactive == 1
    teller2:=teller2 + 1
  return  
PUB instel_setpoint 

       setpoint :=  i2cObject.ReadLong(i2cSCL, EEPROMAddr, $6981)
       teller1 := teller2 :=0                     
  repeat
        punt:= 0
        print(long[@Setpoint])
        
        teller_1
        teller_2
        
        if ina[buton1]==0      and setpoint < 99                     { down scroll button}
           
             Setpoint:= Setpoint + 1
           
         waitcnt (clkfreq / 4+ cnt)

        if ina[buton2]==0    and setpoint > 1                        { down scroll button}
           
             Setpoint:= Setpoint - 1
           
         waitcnt (clkfreq / 4+ cnt)
                
        if ina[buton3]==0 
          waitcnt (clkfreq / 4+ cnt)
          h_menu:=8
          teller1 := teller2 :=0  
          if setpoint ==  i2cObject.ReadLong(i2cSCL, EEPROMAddr, $6981)
            return       
          else
            i2cObject.WriteLong(i2cSCL, EEPROMAddr, $6981, setpoint)
            return
            
        if ina[buton4]==0 
          waitcnt (clkfreq / 4+ cnt)
          h_menu:= 6
          teller1 := teller2 :=0  
          if setpoint ==  i2cObject.ReadLong(i2cSCL, EEPROMAddr, $6981)
            return       
          else
            i2cObject.WriteLong(i2cSCL, EEPROMAddr, $6981, setpoint)
            return

          
        if teller1 > 60000                                { return to Temp Reading if Noting Happening for 30 sec }
           teller1 := 0
           notactive := 1
        
        if teller2 > 30000                               { Scroll from Temp to RV% after 45 sec nothing happen}
           teller2 := 0
           h_menu := 1

           if setpoint ==  i2cObject.ReadLong(i2cSCL, EEPROMAddr, $6981)
            return       
           else
            i2cObject.WriteLong(i2cSCL, EEPROMAddr, $6981, setpoint)
            return
       
PUB instel_Offset 

       offset :=  i2cObject.ReadLong(i2cSCL, EEPROMAddr, $6977)
       teller1 := teller2 := 0                      
  repeat
        punt:= 0
        print(long[@Offset])
        teller_1
        
        if ina[buton1]==0      and offset < 10                     { down scroll button}
           
             Offset:= Offset + 1
           
         waitcnt (clkfreq / 4+ cnt)

        if ina[buton2]==0    and Offset > 1                        { down scroll button}
           
             Offset:= Offset - 1
           
         waitcnt (clkfreq / 4+ cnt)
                
        if ina[buton3]==0 
          waitcnt (clkfreq / 4+ cnt)
          h_menu:=1
          teller1 := teller2 :=0  
          if Offset ==  i2cObject.ReadLong(i2cSCL, EEPROMAddr, $6977)
            return       
          else
            i2cObject.WriteLong(i2cSCL, EEPROMAddr, $6977, Offset)
            return
            
        if ina[buton4]==0 
          waitcnt (clkfreq / 4+ cnt)
          h_menu:= 7
          teller1 := teller2 :=0  
          if Offset ==  i2cObject.ReadLong(i2cSCL, EEPROMAddr, $6977)
            return       
          else
            i2cObject.WriteLong(i2cSCL, EEPROMAddr, $6977, Offset)
            return


        if teller1 > 60000                                { return to Temp Reading if Noting Happening for 30 sec }
           teller1 := 0
           notactive := 1
        
        if teller2 > 30000                               { Scroll from Temp to RV% after 45 sec nothing happen}
           teller2 := 0
           h_menu := 1

           if Offset ==  i2cObject.ReadLong(i2cSCL, EEPROMAddr, $6977)
              return       
           else
              i2cObject.WriteLong(i2cSCL, EEPROMAddr, $6977, Offset)
              return

PUB Tempcontrol       | status 

    dira[Relay_1]~~
    templock:=locknew
  
    
    sht.start(SHT_DATA,SHT_CLK)
    f.start
    
    lvmax := i2cObject.ReadLong(i2cSCL, EEPROMAddr, $6997)
    lvmin := i2cObject.ReadLong(i2cSCL, EEPROMAddr, $6993)
    tempmax := i2cObject.ReadLong(i2cSCL, EEPROMAddr, $6989)
    tempmin := i2cObject.ReadLong(i2cSCL, EEPROMAddr, $6985)
    
  repeat 
    repeat until not lockset(templock)    
      sht.config(33,sht#off,sht#yes,sht#hires)
      tempC := celsius(f.FFloat(sht.readHumidity))
      tempC1 := F.FMul(celsius(f.FFloat(sht.readTemperature)),10.0)     {floating point raw measurement temp}
      tempC2 := fp.FloatToFormat(tempC1, 2, 0)               { string for the display}
      bytemove(@Temp, tempC2, strsize(tempC2) +1)      { copy string }
      tempC3 :=f.FTrunc(tempC1)                              { integer to calculate/use  }
      
     
      lv1 := humidity(tempC, f.FFloat(sht.readHumidity))   {floating poitn ram measurement RH }
      lv2 := fp.FloatToFormat(lv1, 2, 0)                    { string for the display}
      bytemove(@Lv, lv2, strsize(lv2) +1)            { copy string }
      lv3 :=f.FTrunc(lv1)
      lockclr(templock)
    '''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''  

    if tempmin == 0                                    '' max/ min temp geheugen ''
        if tempC3 < 999 and tempC3 > 0                   { remove faulty readings from getting stored in history "boundaries"} 
           tempmin:=tempC3
                 
    if tempC3 > tempmax
        if tempC3 < 999 and tempC3 > 0                   { remove faulty readings from getting stored in history "boundaries" }
          tempmax := tempC3
          i2cObject.WriteLong(i2cSCL, EEPROMAddr, $6989, tempC3)
           
    if tempC3 < tempmin
       if tempC3 < 999 and tempC3 > 0                   { remove faulty readings from getting stored in history "boundaries"} 
         tempmin := tempC3   
         i2cObject.WriteLong(i2cSCL, EEPROMAddr, $6985, tempC3)

    ''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
    if lvmin == 0                                    '' max/ min lv geheugen ''
       if lv3 < 99 and lv3 > 10                   { remove faulty readings from getting stored in history boundaries } 
           lvmin:=lv3
                 
    if lv3 > lvmax
       if lv3 < 99 and lv3 > 10                   { remove faulty readings from getting stored in history boundaries }
          lvmax := lv3                                 
          i2cObject.WriteLong(i2cSCL, EEPROMAddr, $6997, lv3)
                     
    if lv3 < lvmin
       if lv3 < 99 and lv3 > 10                   { remove faulty readings from getting stored in history boundaries }  
          lvmin := lv3   
          i2cObject.WriteLong(i2cSCL, EEPROMAddr, $6993, lv3) 
    ''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''           
    if lv3 < (setpoint - offset)
           status:=1

    if lv3 > (setpoint + offset)
        status:=0
        

    if status == 1
         outa[Relay_1]~~ 
    else
         outa[Relay_1]~


    waitcnt(clkfreq + cnt)


PUB print(waarde)
                           
  incode(waarde)
  waitcnt(clkfreq/240 + cnt)
  decode(waarde)
  waitcnt(clkfreq/140 + cnt) 
PUB decode(invoer)

  waarde1 := invoer / 10
  waarde11 := waarde1 * 10
  dig1 := invoer - waarde11

  case dig1    
    0: dig11 := 1056964608
    1: dig11 := 100663296
    2: dig11 :=  1526726656
    3: dig11 :=  1325400064
    4: dig11 :=  1711276032
    5: dig11 :=  1828716544
    6: dig11 :=  2097152000
    7: dig11 :=  117440512
    8: dig11 :=  2130706432
    9: dig11 :=  1862270976
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''

  waarde2 := waarde1 / 10
  waarde22 := waarde2 * 10
  dig2 := waarde1 - waarde22

  case dig2    
    0: dig22 := 4128768 
    1: dig22 := 393216  
    2: dig22 :=  5963776 
    3: dig22 :=  5177344 
    4: dig22 :=  6684672 
    5: dig22 :=  7143424 
    6: dig22 :=  8192000 
    7: dig22 :=  458752  
    8: dig22 :=  8323072 
    9: dig22 :=  7274496 

  if waarde1 == 0  and invoer > 0                        { 0004 weghalen }
     dig22 := 0 

  if waarde1 == 0  and invoer == 0                        { 0004 weghalen }
     dig22 := 0    
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''

  waarde3 := waarde2 / 10
  waarde33 := waarde3 * 10
  dig3 := waarde2 - waarde33

  case dig3    
    0: dig33 := 16128
    1: dig33 := 1536
    2: dig33 :=  23296
    3: dig33 :=  20224
    4: dig33 :=  26112
    5: dig33 :=  27904
    6: dig33 :=  32000
    7: dig33 :=  1792
    8: dig33 :=  32512
    9: dig33 :=  28416

  if waarde2 == 0  and waarde1 > 0                       { 0004 weghalen }
     dig33 := 0

  if waarde2 == 0  and waarde1 == 0 
     dig33 := 0  
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
 
  case waarde3    
    
    1: dig44 := 6
    2: dig44 :=  91
    3: dig44 :=  79
    4: dig44 :=  102
    5: dig44 :=  109
    6: dig44 :=  125
    7: dig44 :=  7
    8: dig44 :=  127
    9: dig44 :=  111

  if waarde3 == 0                                        { 0004 weghalen }
     dig44 := 0
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''      
  

  if punt == 1
    shift.Out( dig11 + dig22 + dig33 + dig44 + 8388608  )

  if punt == 0
     shift.Out( dig11 + dig22 + dig33 + dig44 )   
  

 
  return
PUB  incode(invoer)

  waarde1 := invoer / 10
  waarde11 := waarde1 * 10
  dig1 := invoer - waarde11

  case dig1    
    0: dig11 := 3221225472
    1: dig11 := 4177526784
    2: dig11 :=  2751463424
    3: dig11 :=  2952790016
    4: dig11 :=  2566914048
    5: dig11 :=  2449473536
    6: dig11 :=  2181038080
    7: dig11 :=  4160749568
    8: dig11 :=  2147483648
    9: dig11 :=  2415919104
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''

  waarde2 := waarde1 / 10
  waarde22 := waarde2 * 10
  dig2 := waarde1 - waarde22

  case dig2    
    0: dig22 := 12581912
    1: dig22 := 16318464
    2: dig22 :=  10747904
    3: dig22 :=  11534336
    4: dig22 :=  10027008
    5: dig22 :=  9568256
    6: dig22 :=  8519680
    7: dig22 :=  16252928
    8: dig22 :=  8388608
    9: dig22 :=  9437184

  if waarde1 == 0  and invoer > 0                        { 0004 weghalen }
     dig22 := 16711680

  if waarde1 == 0  and invoer == 0                        { 0004 weghalen }
     dig22 := 16711680
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''

  waarde3 := waarde2 / 10
  waarde33 := waarde3 * 10
  dig3 := waarde2 - waarde33

  case dig3    
    0: dig33 := 49152
    1: dig33 := 63744
    2: dig33 :=  41984
    3: dig33 :=  45056
    4: dig33 :=  39168
    5: dig33 :=  37376
    6: dig33 :=  33280
    7: dig33 :=  63488
    8: dig33 :=  32768
    9: dig33 :=  36864

  if waarde2 == 0  and waarde1 > 0                       { 0004 weghalen }
     dig33 := 65280

  if waarde2 == 0  and waarde1 == 0 
     dig33 := 65280  
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
 
  case waarde3    
    
    1: dig44 := 249
    2: dig44 :=  164
    3: dig44 :=  176
    4: dig44 :=  153
    5: dig44 :=  146
    6: dig44 :=  130
    7: dig44 :=  248
    8: dig44 :=  128
    9: dig44 :=  144

  if waarde3 == 0                                        { 0004 weghalen }
     dig44 := 255
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''      


  if punt == 1
     shift.Out( dig11 + dig22 + dig33 + dig44  - 8388608)   

  if punt == 0
     shift.Out( dig11 + dig22 + dig33 + dig44 )   

 
  return
    
PUB celsius(t)
  ' from SHT1x/SHT7x datasheet using value for 3.5V supply
  ' celsius = -39.7 + (0.01 * t)
  return f.FAdd(-39.7, f.FMul(0.01, t))  
  
PUB humidity(t, rhh) | rhLinear
  ' rhLinear = -2.0468 + (0.0367 * rh) + (-1.5955E-6 * rh * rh)
  ' simplifies to: rhLinear = ((-1.5955E-6 * rh) + 0.0367) * rh -2.0468
  rhLinear := f.FAdd(f.FMul(f.FAdd(0.0367, f.FMul(-1.5955E-6, rhh)), rhh), -2.0468)
  ' rhTrue = (t - 25.0) * (0.01 + 0.00008 * rawRH) + rhLinear
  return f.FAdd(f.FMul(f.FSub(t, 25.0), f.FAdd(0.01, f.FMul(0.00008, rhh))), rhLinear)

PUB step1
  
    led.start(@numleds_)
    leds[0] := 0
    leds[1] := 0
    leds[2] := 0
    leds[3] := 0
    leds[4] := 0
    leds[5] := 0
    leds[6] := 1
                            
PUB step2
  
    led.start(@numleds_)
    leds[0] := 0
    leds[1] := 0
    leds[2] := 0
    leds[3] := 0
    leds[4] := 0
    leds[5] := 1
    leds[6] := 0 
 
PUB step3
  
    led.start(@numleds_)
    leds[0] := 0
    leds[1] := 0
    leds[2] := 0
    leds[3] := 1
    leds[4] := 0
    leds[5] := 0
    leds[6] := 1 
 
PUB step4
  
    led.start(@numleds_)
    leds[0] := 0
    leds[1] := 0
    leds[2] := 1
    leds[3] := 0
    leds[4] := 0
    leds[5] := 0
    leds[6] := 1 
 
PUB step5
  
    led.start(@numleds_)
    leds[0] := 0
    leds[1] := 0
    leds[2] := 0
    leds[3] := 1
    leds[4] := 0
    leds[5] := 1
    leds[6] := 0 
 
PUB step6
  
    led.start(@numleds_)
    leds[0] := 0
    leds[1] := 0
    leds[2] := 1
    leds[3] := 0
    leds[4] := 0
    leds[5] := 1
    leds[6] := 0 

PUB step7
  
    led.start(@numleds_)
    leds[0] := 0
    leds[1] := 1
    leds[2] := 0
    leds[3] := 0
    leds[4] := 0
    leds[5] := 0
    leds[6] := 0    

PUB step8
        
    led.start(@numleds_)
    leds[0] := 1
    leds[1] := 0
    leds[2] := 0
    leds[3] := 0
    leds[4] := 0
    leds[5] := 0
    leds[6] := 0

PUB Intro

     repeat 30
       shift.Out( 1979711488)                  {  H  }
       waitcnt(clkfreq/240 + cnt)

       shift.Out(2298478592+255+16711680+65280)
       waitcnt(clkfreq/140 + cnt)
       
     repeat 30                         
       shift.Out( 7733248+1996488704)          {  HA  }
       waitcnt(clkfreq/240 + cnt)

       shift.Out(8978432+2281701376+255+65280)
       waitcnt(clkfreq/140 + cnt)

       
     repeat 30                         
       shift.Out( 30208+7798784+939524096)
       waitcnt(clkfreq/240 + cnt)              {  HAL  }

       shift.Out(35072+8912896+3338665984+255)
       waitcnt(clkfreq/140 + cnt)

    
     repeat 30                         
       shift.Out(118+30464+3670016+939524096 )
       waitcnt(clkfreq/240 + cnt)              {  HALL  }

       shift.Out(137+34816+13041664+3338665984)
       waitcnt(clkfreq/140 + cnt)

            
     repeat 30                         
       shift.Out(119+14336+3670016+1056964608 )
       waitcnt(clkfreq/240 + cnt)              {  ALLO  }

       shift.Out(136+50944+13041664+3221225472)
       waitcnt(clkfreq/140 + cnt)  

     repeat 30                         
       shift.Out(56+14336+4128768 )
       waitcnt(clkfreq/240 + cnt)              {  LLO_  }

       shift.Out(199+50944+12582912+4278190080)
       waitcnt(clkfreq/140 + cnt)

     repeat 30                         
       shift.Out( 56+16128+100663296)
       waitcnt(clkfreq/240 + cnt)              {  LO_I  }

       shift.Out(199+49152+4177526784+16711680)
       waitcnt(clkfreq/140 + cnt)

     
     repeat 30                         
       shift.Out( 63+393216+956301312)
       waitcnt(clkfreq/240 + cnt)              {  O_IC  }

       shift.Out(192+16318464+3321888768+65280)
       waitcnt(clkfreq/140 + cnt)

     repeat 30                         
       shift.Out(1536+3735552+2030043136 )
       waitcnt(clkfreq/240 + cnt)              {  _ICE  }

       shift.Out(63744+12976128+2248146944+255)
       waitcnt(clkfreq/140 + cnt)

     repeat 150                         
       shift.Out(6+14592+7929856 )
       waitcnt(clkfreq/240 + cnt)              {  ICE_  }

       shift.Out(249+50688+8781824+4278190080)
       waitcnt(clkfreq/140 + cnt)


DAT
  index byte  "HTTP/1.1 200 OK", CR, LF, {
}             "Content-Type: text/html", CR, LF, CR, LF, {
}             "<!DOCTYPE html PUBLIC '-//W3C//DTD XHTML 1.0 Transitional//EN' 'http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd'>", CR, LF, {
}             "<html  xmlns='http://www.w3.org/1999/xhtml'>" , CR, LF, {
}             "<head><meta http-equiv='Content-Type' content='text/html; charset=utf-8' />", CR, LF, {

}             "<meta name='viewport' content='width=device-width, initial-scale=1, maximum-scale=1'>", CR, LF, { 
}             "<meta name='description' content='An ICE Control Production.' >", CR, LF, { 
}             "<title>PX-100D</title>", CR, LF, {

}             "<link rel='stylesheet' href='http://192.168.2.151/test/style22.css' type='text/css' media='screen' />", CR, LF, { 
}             "<link rel='stylesheet' href='http://192.168.2.151/test/graph-style.css' type='text/css' media='screen' />", CR, LF, {
}             "<script type='text/javascript' src='http://192.168.2.151/test/graph.js'></script>", CR, LF, {

}             "<script type='text/javascript'>" , CR, LF, {

}                       "window.onload = function() {", CR, LF, {
}                       "g_graph = new Graph({", CR, LF, {
}                       "'id': 'firstgraph',", CR, LF, {
}                       "'strokeStyle': '#819C58',", CR, LF, {      
}                       "'fillStyle': 'rgba(64,128,0,0.25)',", CR, LF, {
}                       "'grid': [5,10],", CR, LF, { 
}                       "'range': [0,40],", CR, LF, { 
}                       "'call': function(){ return ( Math.floor(latestTemp())); }", CR, LF, {
}                       "});", CR, LF, {

}                       "second_graph = new Graph({", CR, LF, {
}                       "'id': 'secondgraph',", CR, LF, {
}                       "'strokeStyle': '#819C58',", CR, LF, {
}                       "'fillStyle': 'rgba(64,128,0,0.25)',", CR, LF, {
}                       "'grid': [10,20],", CR, LF, { 
}                       "'range': [0,100],", CR, LF, {
}                       "'call': function(){ return ( Math.floor(latestHumidity())); }", CR, LF, {
}                       "});}", CR, LF, {

}             "</script>", CR, LF, {

}             "<script type='text/javascript'>", CR, LF, {
}                        "setInterval(", $22, "getRequest('xmltemp', 'placeholder')", $22, ", 1000);", CR, LF, {        
}             "</script>", CR, LF, {
}             "</head>", CR, LF, {


}             "<script type='text/javascript'>" , CR, LF, {

}                       "function toggleDraw() { g_graph.toggleDraw(); }", CR, LF, {
}                       "function toggleValue(value) { g_graph.toggleValue(value); }", CR, LF, {
}                       "function setFill(val) { if(val == undefined) val = getRandomRGBA(); g_graph.setValue('fillStyle',val); }", CR, LF, {
}                       "function setColor(val) { if(val == undefined) val = getRandomRGB(); g_graph.setValue('strokeStyle',val); }", CR, LF, {
}                       "function getRandomRGB() { return 'rgb(' + Math.floor(Math.random()*255)  + ', ' + Math.floor(Math.random()*255) + ', ' + Math.floor(Math.random()*255) + ')'; }", CR, LF, {
}                       "function getRandomRGBA() { return 'rgba(' + Math.floor(Math.random()*255)  + ', ' + Math.floor(Math.random()*255) + ', ' + Math.floor(Math.random()*255) + ', ' + '0.25)'; }", CR, LF, {
}                       "function clearGraph() { g_graph.clearGraph(); }", CR, LF, {

}                       "function toggleDrawsecond() { second_graph.toggleDraw(); }", CR, LF, {
}                       "function toggleValuesecond(value) { second_graph.toggleValue(value); }", CR, LF, {
}                       "function setFillsecond(val) { if(val == undefined) val = getRandomRGBAsecond(); second_graph.setValue('fillStyle',val); }", CR, LF, {
}                       "function setColorsecond(val) { if(val == undefined) val = getRandomRGBsecond(); second_graph.setValue('strokeStyle',val); }", CR, LF, {
}                       "function getRandomRGBsecond() { return 'rgb(' + Math.floor(Math.random()*255)  + ', ' + Math.floor(Math.random()*255) + ', ' + Math.floor(Math.random()*255) + ')'; }", CR, LF, {
}                       "function getRandomRGBAsecond() { return 'rgba(' + Math.floor(Math.random()*255)  + ', ' + Math.floor(Math.random()*255) + ', ' + Math.floor(Math.random()*255) + ', ' + '0.25)'; }", CR, LF, {
}                       "function clearGraphsecond() { second_graph.clearGraph(); }", CR, LF, {

}             "</script>", CR, LF, {



}             "<header id='top-bar' class='bar'>", CR, LF, { 
}                       "<h1><a href='http://192.168.2.151/web_home.php' target='_blank'>ICE-Control.nl</a></h1>", CR, LF, {
}                       "<p class='copyright'>&copy; 2012</p>", CR, LF, {  
}             "</header>", CR, LF, {      


}             "<div id='logo1'><img src='http://192.168.2.151/test/Logo_website.jpg' alt='logo' width='250' hight='150'title='ICE Control Logo'/>", CR, LF, {            
}             "</div>", CR, LF, {



}             "<div id='graph1'>  ", CR, LF, { 
}                       "<article id='post' role='main'>", CR, LF, {     
}                       "<div><canvas id='firstgraph' width='940' height='200'></canvas>", CR, LF, {   
}             "</div>", CR, LF, {         
}             "</div>", CR, LF, { 
  
  
}             "<div id='graph2'>  ", CR, LF, {  
}                       "<article id='post' role='main'>", CR, LF, { 
}                       "<div><canvas id='secondgraph' width='940' height='400'></canvas>", CR, LF, {    

}             "</div>", CR, LF, {   
}             "</div>", CR, LF, {


}             "<div id='graphpanel1'>                                                                                             ", CR, LF, {


}             "<table>                                                                                                           ", CR, LF, {
  

}                       "<tr>                                                                                                    ", CR, LF, {
}                               "<tr> <td rowspan='2'> <div><span id='tmax'></span> C</div> </td></tr>                           ", CR, LF, {    
}                               " <td><div><span id='placeholder'></span> C</div> </td>                                          ", CR, LF, {
}                       "</tr>                                                                                                   ", CR, LF, {    

}                       "<tr>                                                                                                    ", CR, LF, {    
}                               "<td><div><span id='tmin'></span> C</div></td>                                                   ", CR, LF, {
}                       "</tr>                                                                                                   ", CR, LF, {    

}             "</table>                                                                                                          ", CR, LF, {



 
}             "</div>                                                                                                                                   ", CR, LF, {  

}             "<div id='graphpanel2'>                                                                                                                   ", CR, LF, {

}             "<table>                                                                                                           ", CR, LF, {


}                       "<tr>                                                                                                    ", CR, LF, {
}                               "<tr> <td rowspan='2'> <div><span id='lvmax'></span> %</div> </td></tr>                           ", CR, LF, {    
}                               " <td><div><span id='placeholder2'></span> %</div> </td>                                          ", CR, LF, {
}                       "</tr>                                                                                                   ", CR, LF, {    

}                       "<tr>                                                                                                    ", CR, LF, {    
}                               "<td><div><span id='lvmin'></span> %</div></td>                                                   ", CR, LF, {
}                       "</tr>                                                                                                   ", CR, LF, {    

}             "</table>                                                                                                          ", CR, LF, {

}             "</div>                                                                                                                                   ", CR, LF, {
}             "<header id='bottom-bar' class='bar1'>", CR, LF, { 
}                       "<h1>ICE Control</h1>", CR, LF, {
}                       "<h1>Green, Out Of The Box</h1>", CR, LF, {  
}             "</header>", CR, LF, { 
}             "</body>                                                                                                                                  ", CR, LF, {
}             "</html>                                                                                                                                  ", 0



  halo byte  "HTTP/1.1 200 OK", CR, LF, {
}             "Content-Type: text/html", CR, LF, CR, LF, {
}             "<!DOCTYPE html PUBLIC '-//W3C//DTD XHTML 1.0 Transitional//EN' 'http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd'>", CR, LF, {
}             "<html  xmlns='http://www.w3.org/1999/xhtml'>" , CR, LF, {
}             "<head><meta http-equiv='Content-Type' content='text/html; charset=utf-8' />", CR, LF, {
}             "<title>HALO</title>", CR, LF, {


}             "</head>", CR, LF, {
}             "<body>", CR, LF, {

}             "<div>", CR, LF, {
}             "<a href='index.html'> kas </a>", CR, LF, {  
}             "<a href='halo'> Test </a>", CR, LF, {
}             "</div>", CR, LF, {  


}             "</body>", CR, LF, {
}             "</html>", 0





  xml   byte  "HTTP/1.1 200 OK", CR, LF, {
  }           "Content-Type: text/xml", CR, LF, CR, LF, {
  }           "<?xml version='1.0' encoding='utf-8'?><root><temp>"
  temperature  byte  $30, $30, $2E, $30,        "</temp><humidity>"
  lvlv         byte  $30, $30,                      "</humidity><tmax>"
  t_max        byte  $30, $30, $2E, $30,           "</tmax><tmin>"
  t_min        byte  $30, $30, $2E, $30,           "</tmin><lvmax>"
  lv_max       byte  $30, $30,                    "</lvmax><lvmin>"
  lv_min       byte  $30, $30,                    "</lvmin><setpoint>"
  set_p       byte  $30, $30,                    "</setpoint><offset>"
  off_s       byte  $30, $30,                    "</offset></root>", 0
  
  buff  byte  $0[BUFFER_2K]
  resPtr long $0[25]
